@@ -3,17 +3,21 @@ a command-line interface to the command line, a la pythonpaste
 """
 
 import inspect
-import json
 import os
 import sys
 from optparse import OptionParser
 from pprint import pprint
 
+try:
+    import json
+except ImportError:
+    import simplejson as json
+
 __all__ = ['Undefined', 'CommandParser']
 
 class Undefined(object):
-  def __init__(self, default):
-    self.default=default
+    def __init__(self, default):
+        self.default=default
 
 class CommandParser(OptionParser):
     # TODO: add `help` command
